Index: src/compiler/type-hint-analyzer.cc |
diff --git a/src/compiler/type-hint-analyzer.cc b/src/compiler/type-hint-analyzer.cc |
index 42c4627b67bf50c3fbabd1837c13c9b1afef0ed9..da4f2683a301fc94b87f5fe5a02aaecb6bfe6eb2 100644 |
--- a/src/compiler/type-hint-analyzer.cc |
+++ b/src/compiler/type-hint-analyzer.cc |
@@ -48,10 +48,10 @@ bool TypeHintAnalysis::GetToBooleanHints(TypeFeedbackId id, |
if (i == infos_.end()) return false; |
Handle<Code> code = i->second; |
DCHECK_EQ(Code::TO_BOOLEAN_IC, code->kind()); |
- ToBooleanStub stub(code->GetIsolate(), code->extra_ic_state()); |
-// TODO(bmeurer): Replace ToBooleanStub::Types with ToBooleanHints. |
-#define ASSERT_COMPATIBLE(NAME, Name) \ |
- STATIC_ASSERT(1 << ToBooleanStub::NAME == \ |
+ ToBooleanICStub stub(code->GetIsolate(), code->extra_ic_state()); |
+// TODO(bmeurer): Replace ToBooleanICStub::Types with ToBooleanHints. |
+#define ASSERT_COMPATIBLE(NAME, Name) \ |
+ STATIC_ASSERT(1 << ToBooleanICStub::NAME == \ |
static_cast<int>(ToBooleanHint::k##Name)) |
ASSERT_COMPATIBLE(UNDEFINED, Undefined); |
ASSERT_COMPATIBLE(BOOLEAN, Boolean); |